View source: R/subset_methods.R
| subsetSamples | R Documentation |
Create a SQM or SQMlite object containing only samples specified by the user, and the ORFs, contigs, bins, taxa and functions present in those samples.
subsetSamples(SQM, samples, remove_missing = TRUE, new_sample_names = NULL)
SQM |
SQM or SQMlite object to be subsetted. |
samples |
character. Samples to be included in the subset. |
remove_missing |
bool. If |
new_sample_names |
character. New sample names to be included in the subset (default |
SQM or SQMlite object containing only the requested samples.
subsetTax, subsetFun, subsetORFs, combineSQM. The most abundant items of a particular table contained in a SQM object can be selected with mostAbundant.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.